import java.util.ArrayList;
import java.util.List;
import java.util.Timer;
import java.util.TimerTask;


public class ClassOne {
    protected Two direct;
    protected Two osgi;
    protected Timer timer;
    
    public void startUp() {
        if (timer == null) {
            timer = new Timer();
            timer.schedule(new TimerTask() {
                @Override
                public void run() {
                    benchmark();
                }}, 5000);
        }
    }

    public void shutDown() {

    }

    public void benchmark() {
        List<Long> directList = new ArrayList<Long>();
        List<Long> osgiList = new ArrayList<Long>();
        int loops = 1000;
        int calls = 1000;
        for (int i = 0; i < loops; ++i)
            benchmarkIter(calls, directList, osgiList);

        Double directAvg = average(directList) / (double)calls;
        Double osgiAvg = average(osgiList) / (double)calls;
        System.out.println("Direct: " + directAvg + "ns");
        System.out.println("Osgi: " + osgiAvg + "ns");
        System.out.println("Ratio: " + (osgiAvg / directAvg));
    }

    public Double average(List<Long> list) {
        long accum = 0;
        for (Long l : list)
            accum += l;
        return (double)accum / (double)list.size();
    }

    public void benchmarkIter(Integer calls, List<Long> directList, List<Long> osgiList) {
        Long start = System.nanoTime();
        Integer a = 0;
        Integer total = calls;
        while (a < total)
            a = direct.increment(a);
        Long directTime = System.nanoTime() - start;
        directList.add(directTime);

        start = System.nanoTime();
        a = 0;
        while (a < total)
            a = osgi.increment(a);
        Long osgiTime = System.nanoTime() - start;
        osgiList.add(osgiTime);
    }

    /**
     * @return the direct
     */
    public Two getDirect() {
        return direct;
    }

    /**
     * @param direct the direct to set
     */
    public void setDirect(Two direct) {
        this.direct = direct;
    }

    /**
     * @return the osgi
     */
    public Two getOsgi() {
        return osgi;
    }

    /**
     * @param osgi the osgi to set
     */
    public void setOsgi(Two osgi) {
        this.osgi = osgi;
    }
}
